BEGIN {
  use strict; use warnings;
  my %missing = map {
    eval qq{ require $_ };
    $@ ? ($_=>1) : ()
  } qw( Carp Encode File::Path File::Spec FindBin JSON::PP List::Util Module::CoreList autodie strict version warnings );
  if(%missing)
  {
    print "Your Perl is missing core modules: @{[ sort keys %missing ]}\n";
    print "Ideally if you are using the system Perl you can install the appropriate\n";
    print "package which includes the core Perl modules.  On at least some versions\n";
    print "of Fedora, CentOS and RHEL, this is the `perl-core` package.\n";
    print "\n";
    print " % dnf install perl-core\n";
    print "   ~ or ~\n";
    print " % yum install perl-core\n";
    print "\n";
    print "If you really want to install dual-life modules from CPAN, then you can\n";
    print "use cpanm:\n";
    print "\n";
    print " % cpanm @{[ sort keys %missing ]}\n";
    print "\n";
    print "Note that some core modules are not available from CPAN.\n";
    exit;
  }
}
BEGIN {
  use strict; use warnings;
  unless(eval q{ use 5.014; 1}) {
    print "Perl 5.014 or better required\n";
    exit;
  }
}
# This file was automatically generated by Dist::Zilla::Plugin::Author::Plicease::MakeMaker v(dev).
use strict;
use warnings;
use 5.014;
use ExtUtils::MakeMaker;
use File::ShareDir::Install;

$File::ShareDir::Install::INCLUDE_DOTFILES = 1;
$File::ShareDir::Install::INCLUDE_DOTDIRS  = 1;
install_share dist => "share";

my %WriteMakefileArgs = (
  "ABSTRACT"           => "Dist::Zilla plugins used by Plicease",
  "AUTHOR"             => "Graham Ollis <plicease\@cpan.org>",
  "CONFIGURE_REQUIRES" => {
    "ExtUtils::MakeMaker"     => 0,
    "File::ShareDir::Install" => "0.06"
  },
  "DISTNAME"         => "Dist-Zilla-Plugin-Author-Plicease",
  "LICENSE"          => "perl",
  "MIN_PERL_VERSION" => "5.014",
  "NAME"             => "Dist::Zilla::Plugin::Author::Plicease",
  "PM"               => {
    "lib/Dist/Zilla/MintingProfile/Author/Plicease.pm"         => "\$(INST_LIB)/Dist/Zilla/MintingProfile/Author/Plicease.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease.pm"                 => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/Core.pm"            => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/Core.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/DevShare.pm"        => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/DevShare.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/Init2.pm"           => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/Init2.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/MakeMaker.pm"       => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/MakeMaker.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/MarkDownCleanup.pm" => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/MarkDownCleanup.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/NoUnsafeInc.pm"     => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/NoUnsafeInc.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/SpecialPrereqs.pm"  => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/SpecialPrereqs.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/Tests.pm"           => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/Tests.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/Thanks.pm"          => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/Thanks.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/TravisInstall.pm"   => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/TravisInstall.pm",
    "lib/Dist/Zilla/Plugin/Author/Plicease/Upload.pm"          => "\$(INST_LIB)/Dist/Zilla/Plugin/Author/Plicease/Upload.pm"
  },
  "PREREQ_PM" => {
    "Data::Section"             => 0,
    "Dist::Zilla"               => "6.00",
    "File::ShareDir::Dist"      => 0,
    "File::chdir"               => 0,
    "IPC::System::Simple"       => "1.25",
    "Moose"                     => 0,
    "Path::Tiny"                => 0,
    "Perl::Tidy"                => 0,
    "Sub::Exporter::ForMethods" => 0,
    "namespace::autoclean"      => 0
  },
  "TEST_REQUIRES" => {
    "Test2::V0" => "0.000060"
  },
  "VERSION" => "2.39",
  "test"    => {
    "TESTS" => "t/*.t"
  }
);

my %FallbackPrereqs = (
  "Data::Section"             => 0,
  "Dist::Zilla"               => "6.00",
  "File::ShareDir::Dist"      => 0,
  "File::chdir"               => 0,
  "IPC::System::Simple"       => "1.25",
  "Moose"                     => 0,
  "Path::Tiny"                => 0,
  "Perl::Tidy"                => 0,
  "Sub::Exporter::ForMethods" => 0,
  "Test2::V0"                 => "0.000060",
  "namespace::autoclean"      => 0
);

unless ( eval { ExtUtils::MakeMaker->VERSION(6.63_03) } ) {
  delete $WriteMakefileArgs{TEST_REQUIRES};
  delete $WriteMakefileArgs{BUILD_REQUIRES};
  $WriteMakefileArgs{PREREQ_PM} = \%FallbackPrereqs;
}

delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
  unless eval { ExtUtils::MakeMaker->VERSION(6.52) };

WriteMakefile(%WriteMakefileArgs);

{
  package
    MY;
  use File::ShareDir::Install qw(postamble);
}